# -*- coding: utf-8 -*-
"""
    sphinxcontrib.textstyle
    ~~~~~~~~~~~~~~~~~~~~~~~~

    :copyright: Copyright 2013 by WAKAYAMA Shirou
    :license: BSD, see LICENSE for details.
"""
from __future__ import absolute_import


def setup(app):
    from sphinxcontrib.textstyle import ruby, deleted, color, column

    # delegate to submodules
    ruby.setup(app)
    deleted.setup(app)
    color.setup(app)
    column.setup(app)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from docutils import nodes, utils
from docutils.parsers.rst import Directive, directives
from sphinx.util.nodes import set_role_source_info
from sphinx.locale import _


class deleted(nodes.General, nodes.TextElement, nodes.Inline):
    pass


def visit_deleted(self, node):
    self.body.append(self.starttag(node, 'del', suffix=''))


def depart_deleted(self, node):
    self.body.append('</del>')


def deleted_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
    """Role for del."""
    text = utils.unescape(text)
    node = deleted(rawtext, text)
    set_role_source_info(inliner, lineno, node)
    return [node], []


class DeletedDirective(Directive):
    has_content = True

    def run(self):
        text = '\n'.join(self.content[1:]).strip()

        para = nodes.paragraph()
        para += deleted(text, text)
        return [para]


def setup(app):
    app.add_role('del', deleted_role)
    app.add_node(deleted, html=(visit_deleted, depart_deleted))
    app.add_directive('del', DeletedDirective)



#!/usr/bin/env python
# -*- coding: utf-8 -*-


from docutils.parsers.rst.directives.admonitions import Admonition
from docutils import nodes
from sphinx.locale import _


class ColumnDirective(Admonition):
    node_class = nodes.admonition
    required_arguments = 1

    def run(self):
        self.arguments[0] = self.arguments[0]
        self.options.setdefault('class', []).append(self.name)
        r = Admonition.run(self)
        r[0]['name'] = self.name
        return r


def setup(app):
    app.add_directive('column', ColumnDirective)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from docutils import nodes, utils
from sphinx.util.nodes import split_explicit_title, set_role_source_info


class color(nodes.General, nodes.TextElement, nodes.Inline):
    pass


def visit_color(self, node):
    style = "color: %s" % node['color']
    self.body.append(self.starttag(node, 'span', style=style, suffix=''))


def depart_color(self, node):
    self.body.append('</span>')


def color_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
    """Role for color."""
    text = utils.unescape(text)
    has_explicit, text, colorspec = split_explicit_title(text)

    if not has_explicit:
        # the role does not have color-spec is converted to Text node
        node = nodes.Text(text)
    else:
        node = color(rawtext, text, color=colorspec)

    set_role_source_info(inliner, lineno, node)
    return [node], []


def setup(app):
    app.add_role('color', color_role)
    app.add_node(color, html=(visit_color, depart_color))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from docutils import nodes, utils
from sphinx.util.nodes import split_explicit_title, set_role_source_info


class ruby(nodes.General, nodes.Element, nodes.Inline):
    pass


def visit_ruby(self, node):
    paren_start = self.builder.config.rubytag_rp_start
    paren_end = self.builder.config.rubytag_rp_end

    self.body.append(self.starttag(node, 'ruby', suffix=''))
    self.body.append(self.starttag(node, 'rb', suffix=''))
    self.body.append(node['base'])
    self.body.append('</rb>')
    self.body.append(self.starttag(node, 'rp', suffix=''))
    self.body.append(paren_start)
    self.body.append('</rp>')
    self.body.append(self.starttag(node, 'rt', suffix=''))
    self.body.append(node['text'])
    self.body.append('</rt>')
    self.body.append(self.starttag(node, 'rp', suffix=''))
    self.body.append(paren_end)
    self.body.append('</rp>')
    self.body.append('</ruby>')
    raise nodes.SkipNode


def ruby_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
    """Role for rubytag."""
    text = utils.unescape(text)
    has_explicit, base, text = split_explicit_title(text)

    if not has_explicit:
        # the role does not have ruby-text is converted to Text node
        node = nodes.Text(text)
    else:
        node = ruby(rawtext, base=base, text=text)

    set_role_source_info(inliner, lineno, node)
    return [node], []


def setup(app):
    app.add_role('ruby', ruby_role)
    app.add_node(ruby, html=(visit_ruby, None))
    app.add_config_value('rubytag_rp_start', '(', 'env')
    app.add_config_value('rubytag_rp_end', ')', 'env')
